<?php
/**
 * Replace Value Rules [page]   
 *
 * @package CSV 2 POST
 * @subpackage Views
 * @author Ryan Bayne   
 * @since 8.1.3
 */

// Prohibit direct script loading
defined( 'ABSPATH' ) || die( 'No direct script access allowed!' );

/**
 * Replace Value Rules [page] 
 * 
 * @package CSV 2 POST
 * @subpackage Views
 * @author Ryan Bayne
 * @since 8.1.3
 */
class CSV2POST_Advancedreplacevaluerules_View extends CSV2POST_View {

    /**
     * Number of screen columns for post boxes on this screen
     *
     * @since 8.1.3
     *
     * @var int
     */
    protected $screen_columns = 1;
    
    protected $view_name = 'replacevaluerules';
    
    public $purpose = 'normal';// normal, dashboard

    /**
    * Array of meta boxes, looped through to register them on views and as dashboard widgets
    * 
    * @author Ryan R. Bayne
    * @package CSV 2 POST
    * @since 8.1.33
    * @version 1.1
    */
    public function meta_box_array() {
        // array of meta boxes + used to register dashboard widgets (id, title, callback, context, priority, callback arguments (array), dashboard widget (boolean) )   
        return $this->meta_boxes_array = array(
            // array( id, title, callback (usually parent, approach created by Ryan Bayne), context (position), priority, call back arguments array, add to dashboard (boolean), required capability
            array( 'replacevaluerules-replacevaluerules', __( 'New Rule', 'csv2post' ), array( $this, 'parent' ), 'normal','default',array( 'formid' => 'replacevaluerules' ), true, 'activate_plugins' ),
            array( 'replacevaluerules-replacevaluerulestable', __( 'Rules Table', 'csv2post' ), array( $this, 'parent' ), 'normal','default',array( 'formid' => 'replacevaluerulestable' ), true, 'activate_plugins' ),
        );    
    }
            
    /**
     * Set up the view with data and do things that are specific for this view
     *
     * @since 8.1.3
     *
     * @param string $action Action for this view
     * @param array $data Data for this view
     */
    public function setup( $action, array $data ) {
        global $csv2post_settings;
            
        // create constant for view name
        if(!defined( "CSV2POST_VIEWNAME") ){define( "CSV2POST_VIEWNAME", $this->view_name );}
                
        // load the current project row and settings from that row
        if( isset( $csv2post_settings['currentproject'] ) && $csv2post_settings['currentproject'] !== false ) {
            
            $this->project_object = $this->DB->get_project( $csv2post_settings['currentproject'] ); 
            if( !$this->project_object ) {
                $this->current_project_settings = false;
            } else {
                $this->current_project_settings = maybe_unserialize( $this->project_object->projectsettings ); 
            }
 
            // add view introduction
            $this->add_text_box( 'viewintroduction', array( $this, 'viewintroduction' ), 'normal' );
              
            parent::setup( $action, $data );
            
            // using array register many meta boxes
            foreach( self::meta_box_array() as $key => $metabox ) {
                // the $metabox array includes required capability to view the meta box
                if( isset( $metabox[7] ) && current_user_can( $metabox[7] ) ) {
                    $this->add_meta_box( $metabox[0], $metabox[1], $metabox[2], $metabox[3], $metabox[4], $metabox[5] );   
                }               
            }        
     
        } else {
            $this->add_meta_box( 'posttypes-nocurrentproject', __( 'No Current Project', 'csv2post' ), array( $this->UI, 'metabox_nocurrentproject' ), 'normal','default',array( 'formid' => 'nocurrentproject' ) );      
        }    
    }

    /**
    * Outputs the meta boxes
    * 
    * @author Ryan R. Bayne
    * @package CSV 2 POST
    * @since 8.1.33
    * @version 1.1
    */
    public function metaboxes() {
        parent::register_metaboxes( self::meta_box_array() );     
    }

    /**
    * This function is called when on WP core dashboard and it adds widgets to the dashboard using
    * the meta box functions in this class. 
    * 
    * @uses dashboard_widgets() in parent class CSV2POST_View which loops through meta boxes and registeres widgets
    * 
    * @author Ryan R. Bayne
    * @package CSV 2 POST
    * @since 8.1.33
    * @version 1.1
    */
    public function dashboard() { 
        parent::dashboard_widgets( self::meta_box_array() );  
    }
    
    /**
    * All add_meta_box() callback to this function to keep the add_meta_box() call simple.
    * 
    * This function also offers a place to apply more security or arguments.
    * 
    * @author Ryan R. Bayne
    * @package CSV 2 POST
    * @since 8.1.32
    * @version 1.0.1
    */
    function parent( $data, $box ) {
        eval( 'self::postbox_' . $this->view_name . '_' . $box['args']['formid'] . '( $data, $box );' );
    }

    /**
    * This views dismissable introduction.
    * 
    * @author Ryan R. Bayne
    * @package CSV 2 POST
    * @since 0.0.1
    * @version 1.0
    */
    public function viewintroduction() {
        $main_title = __( 'Replace Value Rules Introduction', 'csv2post' );
        
        $intro = __( 'These rules are applied at the point of post 
        creation unlike the Data Rules view which offers tools to 
        change data when it is imported. We require rules to be applied 
        just before a post is created if the imported data may be 
        updated by third party software i.e. if CSV 2 POST is not 
        the only software imported and updating the data. In that case 
        the Data Rules end up skipped. Replace Value Rules view offers 
        just one example of many rules that could be offered to ensure 
        a third parties data conforms to our websites 
        standards/requirements.', 'csv2post' );
        
        $title = false;//__( 'More Information', 'csv2post' );
        
        $info = false;//__( '<ol><li>Tutorials Coming Soon</li></ol>', 'csv2post' );
        
        $foot = false;//__( 'Get your tutorial link added to this list. Video, blog, forum and PDF documents accepted.', 'csv2post' );
        
        $this->UI->intro_box_dismissible( 'replacevaluerules-introduction', $main_title, $intro, $info_area = true, $title, $info, $foot );               
    }
        
    /**
    * post box function
    * 
    * @author Ryan Bayne
    * @package CSV 2 POST
    * @since 8.1.3
    * @version 1.1
    */
    public function postbox_replacevaluerules_replacevaluerules( $data, $box ) {    
        $this->UI->postbox_content_header( $box['title'], $box['args']['formid'], __( 'A tool that helps us convert values in our data i.e. USD to $ or Unavailable to Sold Out.', 'csv2post' ), false );        
        $this->FORMS->form_start( $box['args']['formid'], $box['args']['formid'], $box['title'] );
        
        global $csv2post_settings;
        ?>  

            <table class="form-table"> 
                <?php 
                $this->UI->option_projectcolumns( __( 'Data Column' ), $csv2post_settings['currentproject'], 'vrvdata', 'vrvdata' );
                $this->UI->option_text( 'Data Value', 'vrvdatavalue', 'vrvdatavalue', '' );
                ?>        
            </table>
            
            <div id="poststuff">
                <?php 
                $cfcontent = '';
                ?>
                <?php wp_editor( $cfcontent, 'vrvreplacementvalue', array( 'textarea_name' => 'vrvreplacementvalue' ) );?>
            </div>
        
        <?php 
        $this->UI->postbox_content_footer();
    }
    
    /**
    * post box function
    * 
    * @author Ryan Bayne
    * @package CSV 2 POST
    * @since 8.1.3
    * @version 1.1
    */
    public function postbox_replacevaluerules_replacevaluerulestable( $data, $box ) {    
        $this->UI->postbox_content_header( $box['title'], $box['args']['formid'], __( 'A list of your replace value rules.', 'csv2post' ), false );        
        $this->FORMS->form_start( $box['args']['formid'], $box['args']['formid'], $box['title'] );
        ?>  

        <?php
        // ensure we have an array
        if(!isset( $this->current_project_settings['content']['valuerules'] ) || !is_array( $this->current_project_settings['content']['valuerules'] ) ){
            $this->current_project_settings['content']['valuerules'] = array();
        }

        $CFTable = new CSV2POST_ReplaceValueRules_Table();
        $CFTable->prepare_items_further( $this->current_project_settings['content']['valuerules'],100);
        ?>
                    
        <form id="movies-filter" method="get">
            <input type="hidden" name="page" value="<?php echo $_REQUEST['page'] ?>" />
            <?php $CFTable->display() ?>
        </form>
        
        <?php 
        $this->UI->postbox_content_footer();
    }  
}?>